package com.vendor.burn.model;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.model.BoardConfig;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.LocalConfig;
import com.vendor.burn.model.PlatformType;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.devices.IDeviceSetting;
import com.vendor.burn.model.devices.IUIAdapter;
import java.util.HashMap;
import java.util.Map;

public class BurnContext {
  private static final Map<Integer, Integer> baudRateMap = new HashMap<>();
  
  private final LocalConfig localConfig;
  
  private final BoardConfig boardConfig;
  
  private int jtagFrequency;
  
  private int stopBit;
  
  private int parity;
  
  static {
    baudRateMap.put(Integer.valueOf(0), Integer.valueOf(115200));
    baudRateMap.put(Integer.valueOf(1), Integer.valueOf(230400));
    baudRateMap.put(Integer.valueOf(2), Integer.valueOf(380400));
    baudRateMap.put(Integer.valueOf(3), Integer.valueOf(460800));
    baudRateMap.put(Integer.valueOf(4), Integer.valueOf(921600));
    baudRateMap.put(Integer.valueOf(5), Integer.valueOf(2000000));
    baudRateMap.put(Integer.valueOf(6), Integer.valueOf(3000000));
    baudRateMap.put(Integer.valueOf(7), Integer.valueOf(4000000));
  }
  
  private TransferWay transferWay = TransferWay.Net;
  
  private int dwTimeout = 13;
  
  private boolean usbToEthernet = false;
  
  private FlashType currFlashType = FlashType.emmc;
  
  private PlatformType platformType = PlatformType.NonCA;
  
  private IUIAdapter UIAdapter;
  
  private IDeviceSetting deviceSetting;
  
  private boolean tftpOccupied;
  
  public BurnContext() {
    this.localConfig = new LocalConfig();
    this.boardConfig = new BoardConfig();
  }
  
  public LocalConfig getLocalConfig() {
    return this.localConfig;
  }
  
  public IDeviceSetting getDeviceSetting() {
    return this.deviceSetting;
  }
  
  public void setDeviceSetting(IDeviceSetting deviceSetting) {
    this.deviceSetting = deviceSetting;
  }
  
  public BoardConfig getBoardConfig() {
    return this.boardConfig;
  }
  
  public IUIAdapter getUIAdapter() {
    return this.UIAdapter;
  }
  
  public void setUIAdapter(IUIAdapter uIAdapter) {
    this.UIAdapter = uIAdapter;
  }
  
  public int getJtagFrequency() {
    return this.jtagFrequency;
  }
  
  public void setJtagFrequency(int jtagFrequency) {
    this.jtagFrequency = jtagFrequency;
  }
  
  public TransferWay getTransferWay() {
    return this.transferWay;
  }
  
  public void setTransferWay(TransferWay transferWay) {
    this.transferWay = transferWay;
  }
  
  public int getDwTimeout() {
    return this.dwTimeout;
  }
  
  public void setDwTimeout(int dwTimeout) {
    this.dwTimeout = dwTimeout;
  }
  
  public PlatformType getPlatformType() {
    return this.platformType;
  }
  
  public void setPlatformType(PlatformType type) {
    this.platformType = type;
  }
  
  public boolean isTftpOccupied() {
    return this.tftpOccupied;
  }
  
  public void setTftpOccupied(boolean tftpOccupied) {
    this.tftpOccupied = tftpOccupied;
  }
  
  public FlashType getCurrFlashType() {
    return this.currFlashType;
  }
  
  public void setCurrFlashType(FlashType currFlashType) {
    this.currFlashType = currFlashType;
  }
  
  public void setSerialBaudRate(int serialBaudRate) {
    BurnConfig.setBaud(((Integer)baudRateMap.get(Integer.valueOf(serialBaudRate))).intValue());
  }
  
  public void setStopBit(int stopBit) {
    int value = stopBit;
    if (stopBit == 1)
      value = 2; 
    this.stopBit = value;
  }
  
  public int getStopBit() {
    return this.stopBit;
  }
  
  public void setParity(int parity) {
    this.parity = parity;
  }
  
  public int getParity() {
    return this.parity;
  }
  
  public boolean isUsbToEthernet() {
    return this.usbToEthernet;
  }
  
  public void setUsbToEthernet(boolean usbToEthernet) {
    this.usbToEthernet = usbToEthernet;
  }
}
